==> haskell-yesod-static-1.6.0.1-193-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.6.0.1
id: yesod-static-1.6.0.1-JXINZDcZ0KODWr1cTQ5D2t
key: yesod-static-1.6.0.1-JXINZDcZ0KODWr1cTQ5D2t
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
abi: b820f2ac8ec2472e3430daea974c8a51
exposed: True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-static-1.6.0.1
hs-libraries: HSyesod-static-1.6.0.1-JXINZDcZ0KODWr1cTQ5D2t
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-ITlHlOh3QYv9px9t4j8BGR
    css-text-0.1.3.0-GjyyspTxklxH8o1kLaeFXy
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsmin-0.2.0.2-8bbMUyCznUM20RvHxtOzmm
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk process-1.6.5.0
    template-haskell-2.14.0.0 text-1.2.3.1 transformers-0.5.6.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-app-static-3.1.6.3-5M4WXDM0cU6KzUuR5reaPB
    yesod-core-1.6.16.1-IE6TEi1FwiU3ZAuWApXm92
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.0.1-194-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.6.0.1
id: yesod-static-1.6.0.1-Ef7CQZNgpoSBc7otuRomfz
key: yesod-static-1.6.0.1-Ef7CQZNgpoSBc7otuRomfz
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
abi: 02a1004dc6ae076433bbb91676e894b0
exposed: True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-static-1.6.0.1
hs-libraries: HSyesod-static-1.6.0.1-Ef7CQZNgpoSBc7otuRomfz
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-ITlHlOh3QYv9px9t4j8BGR
    css-text-0.1.3.0-GjyyspTxklxH8o1kLaeFXy
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsmin-0.2.0.2-8bbMUyCznUM20RvHxtOzmm
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk process-1.6.5.0
    template-haskell-2.14.0.0 text-1.2.3.1 transformers-0.5.6.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-app-static-3.1.6.3-D3UzEKCcOqL8pqt69ugm0A
    yesod-core-1.6.16.1-3ZUz3YF8YXeKlUSD880OPl
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
